# pds.api-client
Federated PDS API which provides actionable end points standardized
between the different nodes.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.dev
- Package version: 0.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pds.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pds.api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import pds.api_client
from pds.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0
# See configuration.py for a list of all supported configuration parameters.
configuration = pds.api_client.Configuration(
    host = "https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0"
)



# Enter a context with an instance of the API client
with pds.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pds.api_client.BundlesApi(api_client)
    lidvid = 'lidvid_example' # str | lidvid (urn)

    try:
        # bundles URN resolver for lidvid
        api_response = api_instance.bundle_by_lidvid(lidvid)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BundlesApi->bundle_by_lidvid: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://virtserver.swaggerhub.com/PDS_APIs/pds_federated_api/0.1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BundlesApi* | [**bundle_by_lidvid**](docs/BundlesApi.md#bundle_by_lidvid) | **GET** /bundles/{lidvid} | bundles URN resolver for lidvid
*BundlesApi* | [**get_bundles**](docs/BundlesApi.md#get_bundles) | **GET** /bundles | request PDS bundles
*BundlesCollectionsApi* | [**collections_of_a_bundle**](docs/BundlesCollectionsApi.md#collections_of_a_bundle) | **GET** /bundles/{lidvid}/collections | get collections belonging to a given bundle
*CapabilitiesApi* | [**capabilities**](docs/CapabilitiesApi.md#capabilities) | **GET** /capabilities | capabilities api entry point, list the resources provided by the current API end-point.
*CollectionsApi* | [**collections_by_lidvid**](docs/CollectionsApi.md#collections_by_lidvid) | **GET** /collections/{lidvid} | collections URN resolver for lidvid
*CollectionsApi* | [**get_collection**](docs/CollectionsApi.md#get_collection) | **GET** /collections | request PDS collections
*CollectionsProductsApi* | [**products_of_a_collection**](docs/CollectionsProductsApi.md#products_of_a_collection) | **GET** /collections/{lidvid}/products | get producs belonging to a given collection
*ProductsApi* | [**products**](docs/ProductsApi.md#products) | **GET** /products | search across all PDS data products, including bundles, collections, documentation, and observational products,
*ProductsApi* | [**products_by_lidvid**](docs/ProductsApi.md#products_by_lidvid) | **GET** /products/{lidvid} | URN resolver for lidvid
*RoutesApi* | [**all_routes**](docs/RoutesApi.md#all_routes) | **GET** /routes | 
*RoutesApi* | [**routes**](docs/RoutesApi.md#routes) | **GET** /routes/{resource} | 


## Documentation For Models

 - [Capability](docs/Capability.md)
 - [ErrorMessage](docs/ErrorMessage.md)
 - [Metadata](docs/Metadata.md)
 - [Product](docs/Product.md)
 - [Products](docs/Products.md)
 - [Reference](docs/Reference.md)
 - [Route](docs/Route.md)
 - [Summary](docs/Summary.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

pds-operator@jpl.nasa.gov


